@@ -138,7 +138,7 @@ class ComicInfoXml:
         assign("Series", metadata.series.name)
         assign("Number", metadata.issue)
         assign("Count", metadata.issue_count)
-        assign("Volume", metadata.volume)
+        assign("Volume", metadata.series.volume)
         assign("AlternateSeries", metadata.alternate_series)
         assign("AlternateNumber", metadata.alternate_number)
         assign("SeriesGroup", metadata.series_group)
@@ -200,7 +200,7 @@ class ComicInfoXml:
         assign("Web", metadata.web_link)
         assign("PageCount", metadata.page_count)
         assign("LanguageISO", metadata.language)
-        assign("Format", metadata.format)
+        assign("Format", metadata.series.format)
         assign("BlackAndWhite", "Yes" if metadata.black_and_white else None)
         assign("Manga", self.validate_manga(metadata.manga))
         assign("Characters", list_to_string(metadata.characters))
@@ -248,7 +248,7 @@ class ComicInfoXml:
         metadata.stories = string_to_list(xlate(get("Title")))
         metadata.issue = IssueString(xlate(get("Number"))).as_string()
         metadata.issue_count = xlate(get("Count"), True)
-        metadata.volume = xlate(get("Volume"), True)
+        metadata.series.volume = xlate(get("Volume"), True)
         metadata.alternate_series = xlate(get("AlternateSeries"))
         metadata.alternate_number = IssueString(xlate(get("AlternateNumber"))).as_string()
         metadata.alternate_count = xlate(get("AlternateCount"), True)
@@ -266,7 +266,7 @@ class ComicInfoXml:
         metadata.genres = string_to_list(xlate(get("Genre")))
         metadata.web_link = xlate(get("Web"))
         metadata.language = xlate(get("LanguageISO"))
-        metadata.format = xlate(get("Format"))
+        metadata.series.format = xlate(get("Format"))
         metadata.manga = xlate(get("Manga"))
         metadata.characters = string_to_list(xlate(get("Characters")))
         metadata.teams = string_to_list(xlate(get("Teams")))
